@@ -141,7 +141,6 @@ def fill_fstatistic(data, overwrite=False):
     # Primary route: FSTAT = (BETA / SE)² when BETA and SE are available (SE=0 produces inf)
     beta_se_computable = pd.Series([False] * nrows, index=data.index)
     if "BETA" in data.columns and "SE" in data.columns:
-        method = "BETA/SE"
         beta_se_computable = (
             rows_to_compute & 
             data["BETA"].notna() & 
@@ -157,7 +156,6 @@ def fill_fstatistic(data, overwrite=False):
     # Fallback route: FSTAT = χ²_isf(P, df=1) for remaining rows where P is present
     # Allow P=0 (produces inf for extremely significant variants)
     if "P" in data.columns:
-        method = "P-values"
         p_fallback_computable = (
             rows_to_compute & 
             ~beta_se_computable & 
@@ -174,19 +172,19 @@ def fill_fstatistic(data, overwrite=False):
     # Logging
     if column_created:
         print(
-            f"The FSTAT (F-statistic) column has been created using {method}. "
+            f"The FSTAT (F-statistic) column has been created. "
             f"{n_assigned}({n_assigned/nrows*100:.3f}%) values computed."
         )
     elif overwrite:
         print(
-            f"The FSTAT (F-statistic) column has been re-created using {method}. "
+            f"The FSTAT (F-statistic) column has been re-created. "
             f"{n_assigned}({n_assigned/nrows*100:.3f}%) values computed."
         )
     else:
         if n_assigned > 0:
             print(
                 f"The FSTAT (F-statistic) column: {n_assigned}({n_assigned/nrows*100:.3f}%)"
-                f"missing values have been filled using {method}."
+                f"missing values have been filled."
             )
     
     return
@@ -402,7 +400,7 @@ def check_int_column(data, int_col):
         )
     return
 
-def adjust_column_names(data, CHR, POS, SNP, EA, NEA, BETA, SE, P, EAF, keep_columns):
+def adjust_column_names(data, CHR, POS, SNP, EA, NEA, BETA, SE, P, EAF, keep_columns, F):
     """
     Rename columns to the standard names making sure that there are no duplicated names.
     Delete other columns if keep_columns=False, keep them if True.
@@ -422,6 +420,7 @@ def adjust_column_names(data, CHR, POS, SNP, EA, NEA, BETA, SE, P, EAF, keep_col
         SE: "SE",
         P: "P",
         EAF: "EAF",
+        F: "F",
     }
     for key, value in rename_dict.items():
         if key != value and key not in data.columns:
