@@ -52,7 +52,7 @@ def lift_data(
     nrows = data.shape[0]
     data.dropna(subset=["CHR", "POS"], inplace=True)
     # Remove absurd positions
-    data = data[data.POS < 300_000_000]
+    data.drop(data[data.POS >= 300_000_000].index, inplace=True)
     data.reset_index(drop=True, inplace=True)
     n_na = nrows - data.shape[0]
     if n_na:
